@@ -20,6 +20,47 @@ namespace binder {
 using namespace ost;
 using namespace std;
 
+bool Methods::scrFeature(void)
+{
+        BayonneSession *r = getSid(var_recall);
+        Event event;
+	const char *encoding = getKeyword("encoding");
+	timeout_t framing = getTimeoutKeyword("framing");
+	const char *opt;
+	char buf[96];
+
+	dtmf_digits[digit_count] = 0;
+	opt = getValue(dtmf_digits);
+
+        if(r)
+        {
+                memset(&event, 0, sizeof(event));
+                event.id = DROP_RECALL;
+                event.peer = this;
+                r->queEvent(&event);
+        }
+	strcpy(var_recall, "none");
+
+        if(!framing || framing == TIMEOUT_INF)
+                framing = 0;
+
+	if(encoding)
+		if(setReconnect(encoding, framing))
+			return false;
+
+	if(!opt || !*opt)
+	{
+		advance();
+		return true;
+	}
+	snprintf(buf, sizeof(buf), "feature::%s", opt);
+	if(redirect(buf))
+		return false;
+
+	error("no-feature");
+	return true;
+}
+
 bool Methods::scrRelease(void)
 {
 	BayonneSession *r = getSid(var_recall);
@@ -48,8 +89,12 @@ bool Methods::scrRecall(void)
 	if(!r)
 	{
 		error("no-recall");
-		return false;
+		return true;
 	}
+
+	if(recallReconnect())
+		return false;
+
 	strcpy(var_joined, var_recall);
 	strcpy(var_recall, "none");
 	state.timeout = 0;
@@ -97,6 +142,7 @@ bool Methods::scrJoin(void)
 	
 	memset(&event, 0, sizeof(event));
 	event.id = PEER_WAITING;
+	event.peer = this;
 	release();
 	if(!state.join.peer->postEvent(&event))
 	{
