@@ -58,6 +58,7 @@
 #define	MAX_PATHNAME	256
 #define	MIN_AUDIOFEED	(120 * 8)	// 120 millisecond starting
 #define	MAX_AUDIOFEED	(600 * 8)	// 600 millisecond buffer
+#define	RPC_MAX_KEYS	128
 
 #ifdef	WIN32
 #define	PFD_INVALID	INVALID_HANDLE_VALUE
@@ -69,6 +70,12 @@
 #error "ccscript 3 0.8.0 or later required"
 #endif
 
+#ifdef	DEBUG
+#define	SLOG_DEBUG(x, ...)	slog.debug(x, __VA_ARGS__)
+#else
+#define	SLOG_DEBUG(x, ...)
+#endif
+
 namespace ost {
 
 class __EXPORT BayonneMsgport;
@@ -2759,6 +2766,44 @@ public:
 	BayonneAudio audio;
 };
 
+/**
+ * Bayonne RPC arguments, may be passed through to binders from 
+ * webservice sessions for extensions to soap & xmlrpc services.
+ *
+ * @short rpc arguments parsed
+ * @author David Sugar <dyfet@gnutelephony.org>
+ */
+class __EXPORT BayonneRPC : public Bayonne
+{
+protected:
+        struct {
+                const char *name;
+                const char *field;
+                const char *value;
+        }       rpc_keydata[RPC_MAX_KEYS];
+
+        unsigned rpc_keycount, rpc_argcount;
+
+	BayonneRPC();
+
+        void addArg(const char *value);
+        void addKey(const char *key, const char *value, const char *field = NULL);
+
+public:
+        struct {
+                const char *method;
+                const char *tranid;
+                const char *action;
+                const char *resuri;
+        }	header;
+
+	inline unsigned getCount(void)
+		{return rpc_argcount;};
+
+        const char *getArg(unsigned id);
+        const char *getKey(const char *name, const char *field = NULL);
+};	
+	 
 /**
  * Bayonne services are used for threaded modules which may be
  * installed at runtime.  These exist to integrate plugins with
