@@ -44,7 +44,7 @@ void BayonneMsgport::shutdown(void)
 
 	if(msglist)
 	{
-//		slog.debug("%s msgport stopping", msgname);
+		SLOG_DEBUG("%s msgport stopping", msgname);
 	
 		down.timeslot = NO_TIMESLOT;
 		down.id = MSGPORT_SHUTDOWN;
@@ -146,7 +146,7 @@ void BayonneMsgport::run(void)
 	Event event;
 	timeout_t timeout;
 
-	slog.debug("%s msgport starting", msgname);
+	SLOG_DEBUG("%s msgport starting", msgname);
 
 	for(;;)
 	{
