@@ -62,7 +62,7 @@ ScriptInterp(), audio()
 	snprintf(logname, sizeof(logname), "%s/%d",
 		d->getName(), ts - d->getFirst());
 
-	slog.debug("%s: session starting", logname);
+	SLOG_DEBUG("%s: session starting", logname);
 	setState(STATE_INITIAL);
 
 	snprintf(var_timeslot, sizeof(var_timeslot), "%d", timeslot);
@@ -228,7 +228,7 @@ void BayonneSession::finalize(void)
 {
 	purge();
 
-	slog.debug("%s: session stopping", logname);
+	SLOG_DEBUG("%s: session stopping", logname);
 }
 
 const char *BayonneSession::getWritepath(char *buf, size_t len)
@@ -719,7 +719,7 @@ void BayonneSession::startThread(void)
 
 void BayonneSession::enterThread(ScriptThread *thread)
 {
-	slog.debug("%s: entering thread", logname);
+	SLOG_DEBUG("%s: entering thread", logname);
 }
 
 void BayonneSession::exitThread(const char *msg)
@@ -728,9 +728,9 @@ void BayonneSession::exitThread(const char *msg)
 	char *tmp;
 
 	if(msg)
-		slog.debug("%s: exiting thread; reason=%s", logname, msg);
+		SLOG_DEBUG("%s: exiting thread; reason=%s", logname, msg);
 	else
-		slog.debug("%s: exiting thread", logname);
+		SLOG_DEBUG("%s: exiting thread", logname);
 
 	if(msg)
 	{
