@@ -787,6 +787,12 @@ bool Methods::scrSleep(void)
 	return false;
 }
 
+bool Methods::scrAnswer(void)
+{
+	setState(STATE_ANSWER);
+	return false;
+}
+
 bool Methods::scrHangup(void)
 {
 	setState(STATE_HANGUP);
