@@ -171,7 +171,11 @@ static void loading(void)
 	if(cp)
 		bs = atoi(cp) * 1024;
 
-	getcwd(buffer, sizeof(buffer));
+	if(getcwd(buffer, sizeof(buffer)) == NULL)
+	{
+		slog.critical("cannot get current directory; exiting");
+		exit(-1);
+	}
 
 	BayonneSysexec::allocate(keypaths.getLast("libexec"), bs, pri,
 		keypaths.getLast("modexec"));
@@ -198,7 +202,7 @@ static void loading(void)
 		snprintf(buffer, sizeof(buffer), "%s/%s", keypaths.getLast("prompts"), cp);
 		if(isDir(buffer))
 		{
-			slog.debug("using %s as default voice library", cp);
+			slog.info("using %s as default voice library", cp);
 			Bayonne::init_translator = translator;
 			Bayonne::init_voicelib = cp;
 		}
@@ -214,7 +218,7 @@ static void loading(void)
 				keypaths.getLast("prompts"), vlib);
 			if(isDir(buffer))
 			{
-                        	slog.debug("using %s as default voice library", cp);
+                        	slog.info("using %s as default voice library", cp);
                         	Bayonne::init_translator = translator;
                         	Bayonne::init_voicelib = vlib; 
 			}
